@@ -15,7 +15,7 @@ except ImportError:
 from jupyter_core.utils import ensure_async
 from tornado import web
 
-from jupyter_server.auth import authorized
+from jupyter_server.auth.decorator import authorized
 from jupyter_server.utils import url_escape, url_path_join
 
 from ...base.handlers import APIHandler
